==> mule-devkit-annotations-3.7.2-sources.jar: org/mule/api/annotations/Processor.java <==
/**
 * Mule Development Kit
 * Copyright 2010-2012 (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * This software is protected under international copyright law. All use of this software is
 * subject to MuleSoft's Master Subscription Agreement (or other master license agreement)
 * separately entered into in writing between you and MuleSoft. If such an agreement is not
 * in place, you may not use the software.
 */



package org.mule.api.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation marks a method inside a {@link Connector} as a callable from within a Mule flow. Each
 * parameter on this method will be featured as an attribute on the Mule XML invocation.
 */
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.SOURCE)
@Documented
public @interface Processor {
    /**
     * The xml name of the element that will invoke this processor. This is optional and if it is not specified a name
     * will be derived from the name of the method.
     */
    String name() default "";

    /**
     * A user-friendly name for this processor. This name will be displayed in studio.
     */
    String friendlyName() default "";

    /**
     * Setting this value to true will trigger the generation of an {@link org.mule.api.processor.InterceptingMessageProcessor} rather than
     * a {@link org.mule.api.processor.MessageProcessor}. An intercepting processor must receive a {@link org.mule.api.callback.SourceCallback} to trigger the
     * next portion of the chain.
     *
     * @return
     */
    boolean intercepting() default false;
}

==> mule-devkit-annotations-3.9.15-sources.jar: org/mule/api/annotations/Processor.java <==
/**
 * (c) 2003-2015 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */


package org.mule.api.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation marks a method inside a {@link Connector} as a callable operation from within a Mule flow. Each
 * parameter on this method will be featured as an attribute on the Mule XML invocation.
 */
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.SOURCE)
@Documented
public @interface Processor {

    /**
     * The xml name of the element that will invoke this processor. This is optional and if it is not specified a name
     * will be derived from the name of the method.
     */
    String name() default "";

    /**
     * A user-friendly name for this processor. This name will be displayed in studio.
     */
    String friendlyName() default "";

    /**
     * Setting this value to true will trigger the generation of an {@link org.mule.api.processor.InterceptingMessageProcessor} rather than
     * a {@link org.mule.api.processor.MessageProcessor}. An intercepting processor must receive a {@link org.mule.api.callback.SourceCallback} to trigger the
     * next portion of the chain.
     */
    boolean intercepting() default false;
}
